@@ -78,16 +78,19 @@ def calc_fixbond_structures(value_date: str,
     enddates = schedule[1: no_of_dates]
     structures = []
     for i in range(no_of_interests):
+        fv_flow = 0
         if i == no_of_interests - 1:
             cashflow = bond_info.face_value + interests[i].amount()
+            fv_flow = bond_info.face_value
         else :
             cashflow = interests[i].amount()
+    
         thestructure = {"start_date": startdates[i].ISO(),
                         "end_date": enddates[i].ISO(),
                         "payment_date": interests[i].date().ISO(),
                         "face_value": bond_info.face_value,
                         "coupon": bond_info.coupon,
-                        "face_value_flow": bond_info.face_value,
+                        "face_value_flow": fv_flow,
                         "interest": interests[i].amount(),
                         "cashflow": cashflow} 
         
